import sys
from PyQt4.QtCore import *
from PyKDE4.kdecore import *
from PyKDE4.kdeui import *
from PyKDE4.nepomuk import *

class Tagger(QObject):
    def __init__(self, s, d, r):
        self.simulation = s
        self.depth = d
        self.currentDir = r
    def applyTag(self, file, tags):
        if self.simulation:
            print file.absoluteFilePath()
            print tags
        else:
            res = Nepomuk.Resource(file.absoluteFilePath())
            res.setTags(tags)
    def recursiveParse(self, dir = None):
        if dir == None:
            dir = QDir(self.currentDir)
        parts = dir.path().split("/")
        tags = list()
        for part in parts:
            if part == "" or part == "." or part == "..":
                continue
            if self.simulation:
                tags.append(part)
            else:
                tag = Nepomuk.Tag(part)
                tag.setLabel(part)
                tags.append(tag)
        for el in dir.entryInfoList(QDir.AllEntries | QDir.NoDotAndDotDot):
            if el.isDir():
                self.recursiveParse(QDir(el.absoluteFilePath()))
            else:
                self.applyTag(el, tags[self.depth:])    
    def checkNepomukRunning(self):
        if self.simulation:
            return True
        else:
            manager = Nepomuk.ResourceManager.instance()
            manager.init()
            return manager.initialized()

def main():
    dir = None
    depth = 0
    simulation = False
    
    # Application stuff
    aboutData = KAboutData("dir2tag", QByteArray(), ki18n("Directory converter"), "1.0")
    KCmdLineArgs.init(sys.argv, aboutData)
    options = KCmdLineOptions()
    options.add("s").add("dry-run", ki18n("Simulate the execution"))
    options.add("d <value>").add("depth <value>", ki18n("How many directories (starting from root) have to be dropped from the complete path"))
    options.add("+directory", ki18n("The directory to be parsed"))
    options.add("", ki18n("For example, path \"/home/user/Documents/Work/\" with depth 2 will consider only \"Documents\" and \"Work\" as tags to be applied to all files under that directory."))
    KCmdLineArgs.addCmdLineOptions(options)
    
    # Create the application instance and check command line args
    app = KApplication()
    args = KCmdLineArgs.parsedArgs()
    if args.isSet("s"):
        simulation = True
        print "Running in simulation mode."
    if args.isSet("d"):
        depth = int(args.getOption("d"))
    if args.count() == 0:
        print "The directory argument is mandatory."
        sys.exit(1)
    dir = args.arg(0)
    
    tagger = Tagger(simulation, depth, dir)
    
    # This is needed for having Nepomuk running
    if not tagger.checkNepomukRunning():
        print "Nepomuk is not running; please check your installation."
        sys.exit(1)
    
    # Start the parsing
    tagger.recursiveParse()

if __name__ == "__main__":
    main()
