/*
 Copyright (c) 2009-2010 Alessandro Sivieri <alessandro.sivieri@gmail.com>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public License
 along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
*/

#ifndef TAGSFACET_H
#define TAGSFACET_H

#include <QWidget>

#include <Soprano/Util/AsyncQuery>

#include "facet.h"

class TagsFacet : public Facet
{
    Q_OBJECT

    public:
        TagsFacet(QWidget* parent);
        virtual ~TagsFacet();

        void emitTerm(QStringList labels);

    public Q_SLOTS:
        void queryNextResult(Soprano::Util::AsyncQuery* query);
        void queryFinished(Soprano::Util::AsyncQuery* query);
        void queryFreqNextResult(Soprano::Util::AsyncQuery* query);
        void queryFreqFinished(Soprano::Util::AsyncQuery* query);

    protected:
        void doFolderChanged(const QString& folder);
        void doReload();

    Q_SIGNALS:
        void newTag(const QString& tag, const int count);
        void updateFrequency(const QString& label, const int frequency);
        void clear();

    private:
        void loadTags();
        void loadFrequencies();
        QString merge(const QStringList& list) const;

        class Private;
        Private* d;
};

#endif // TAGSFACET_H
