/*
 Copyright (c) 2010 Alessandro Sivieri <alessandro.sivieri@gmail.com>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public License
 along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */

#include <QButtonGroup>
#include <QVBoxLayout>
#include <QSizePolicy>
#include <QGridLayout>
#include <QList>

#include <Soprano/LiteralValue>
#include <Nepomuk/Query/AndTerm>
#include <Nepomuk/Query/ComparisonTerm>
#include <Nepomuk/Query/LiteralTerm>
#include <Nepomuk/Types/Property>

#include "daterangeselectionwidget.h"
#include "nie.h"
#include "datetoolbutton.h"
#include "facetviewdate.h"

using namespace Nepomuk;

FacetViewDate::FacetViewDate(Facet* facet, QWidget* parent): FacetViewButtons(facet, "When?", parent)
{
    DateToolButton* b1 = new DateToolButton(this);
    b1->setText(i18n("Anytime"));
    b1->setPeriod(DateToolButton::Anytime);
    b1->setChecked(true);
    addButton(b1);
    DateToolButton* b2 = new DateToolButton(this);
    b2->setText(i18n("Today"));
    b2->setPeriod(DateToolButton::Today);
    addButton(b2);
    DateToolButton* b3 = new DateToolButton(this);
    b3->setText(i18n("Yesterday"));
    b3->setPeriod(DateToolButton::Yesterday);
    addButton(b3);
    DateToolButton* b4 = new DateToolButton(this);
    b4->setText(i18n("This week"));
    b4->setPeriod(DateToolButton::ThisWeek);
    addButton(b4);
    DateToolButton* b5 = new DateToolButton(this);
    b5->setText(i18n("This month"));
    b5->setPeriod(DateToolButton::ThisMonth);
    addButton(b5);
}

FacetViewDate::~FacetViewDate()
{
}

void FacetViewDate::startDateWidget()
{
    /*DateRangeSelectionWidget* dateBox = new DateRangeSelectionWidget();
    connect(dateBox, SIGNAL(lessButtonClicked(bool)), this, SLOT(switchWidget()));
    connect(dateBox, SIGNAL(rangeChanged(const DateRange&)), this, SLOT(dateChanged(const DateRange&)));*/
}

void FacetViewDate::dateChanged(const DateRange& range)
{
    Query::AndTerm term;
    Query::ComparisonTerm cterm1(
            Types::Property(Vocabulary::NIE::lastModified()),
            Query::LiteralTerm(Soprano::LiteralValue(range.start())),
            Query::ComparisonTerm::GreaterOrEqual);
    Query::ComparisonTerm cterm2(
            Types::Property(Vocabulary::NIE::lastModified()),
            Query::LiteralTerm(Soprano::LiteralValue(range.end())),
            Query::ComparisonTerm::SmallerOrEqual);
    term.addSubTerm(cterm1);
    term.addSubTerm(cterm2);
    getFacet()->emitQueryTermChanged(term);
}

void FacetViewDate::doButtonChanged(QAbstractButton* button)
{
    DateToolButton* b = qobject_cast<DateToolButton*>(button);
    switch (b->getPeriod()) {
        case DateToolButton::Anytime:
            // send and invalid term: the date query part is gone
            getFacet()->emitQueryTermChanged(Query::Term());
            break;
        case DateToolButton::Today:
            dateChanged(DateRange::today());
            break;
        case DateToolButton::Yesterday:
            dateChanged(DateRange::yesterday());
            break;
        case DateToolButton::ThisWeek:
            dateChanged(DateRange::thisWeek());
            break;
        case DateToolButton::ThisMonth:
            dateChanged(DateRange::thisMonth());
            break;
        default:
            // not used
            break;
    }
}

#include "facetviewdate.moc"
