/*
 Copyright (c) 2010 Alessandro Sivieri <alessandro.sivieri@gmail.com>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public License
 along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */

#include "tagsfacet.h"
#include "facetmodel.h"
#include "facetfilterproxysortmodel.h"
#include "facetviewlist.h"

class FacetViewList::Private
{
    public:
        Private(Facet* facet): model(0), f(qobject_cast<TagsFacet*>(facet))
        {
        }
        FacetModel* model;
        QStringList labels;
        TagsFacet* f;
};

FacetViewList::FacetViewList(Facet* facet, QString title, QWidget* parent): FacetView(facet, parent), d(new Private(facet))
{
    setupUi(this);
    m_facetBox->setTitle(title);
    d->model = new FacetModel(m_termList);
    FacetFilterProxySortModel* proxy = new FacetFilterProxySortModel(m_termList);
    proxy->setDynamicSortFilter(true);
    proxy->setSourceModel(d->model);
    proxy->sort(0);
    m_termList->setModel(proxy);
    m_searchLine->setProxy(proxy);
    connect(d->f, SIGNAL(newTag(const QString&, const int)), d->model, SLOT(addNewItem(const QString&, const int)));
    connect(d->f, SIGNAL(updateFrequency(const QString&, const int)), d->model, SLOT(updateFrequency(const QString&, const int)));
    connect(d->f, SIGNAL(clear()), d->model, SLOT(clear()));
    connect(d->model, SIGNAL(itemChecked(const QString&)), this, SLOT(itemChecked(const QString&)));
    connect(d->model, SIGNAL(itemUnchecked(const QString&)), this, SLOT(itemUnchecked(const QString&)));
}

FacetViewList::~FacetViewList()
{
    delete d;
}

void FacetViewList::itemChecked(const QString& label)
{
    d->labels.append(label);
    d->f->emitTerm(d->labels);
}

void FacetViewList::itemUnchecked(const QString& label)
{
    d->labels.removeAll(label);
    d->f->emitTerm(d->labels);
}

#include "facetviewlist.moc"
