/*
 Copyright (c) 2010 Alessandro Sivieri <alessandro.sivieri@gmail.com>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public License
 along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */

#include <QButtonGroup>
#include <QToolButton>
#include <QVBoxLayout>
#include <QSizePolicy>
#include <QList>

#include <Nepomuk/Query/Term>
#include <Nepomuk/Query/ResourceTypeTerm>
#include <Nepomuk/Query/AndTerm>
#include <Nepomuk/Query/OrTerm>
#include <Nepomuk/Query/LiteralTerm>
#include <Nepomuk/Query/ComparisonTerm>
#include <Nepomuk/Types/Property>

#include "typetoolbutton.h"
#include "nfo.h"
#include "nie.h"
#include "facetviewtype.h"

using namespace Nepomuk;

namespace {
class TypeElement
{
    public:
        TypeElement(QString s, TypeToolButton::DocumentType t): text(s), type(t)
        {
        }
        QString text;
        TypeToolButton::DocumentType type;
};
}

class FacetViewType::Private
{
    public:
        Private()
        {
        }
        QList<TypeElement*> terms;
};

FacetViewType::FacetViewType(Facet* facet, QWidget* parent): FacetViewButtons(facet, "What?", parent), d(new Private())
{
    // terms
    d->terms.append(new TypeElement(i18n("All"), TypeToolButton::All));
    d->terms.append(new TypeElement(i18n("Documents"), TypeToolButton::Documents));
    d->terms.append(new TypeElement(i18n("Images"), TypeToolButton::Images));
    d->terms.append(new TypeElement(i18n("Media"), TypeToolButton::Media));

    for (int i = 0; i < d->terms.size(); ++i) {
        TypeToolButton* b = new TypeToolButton(this);
        b->setText(d->terms[i]->text);
        b->setType(d->terms[i]->type);
        if (i == 0) {
            b->setChecked(true);
        }
        addButton(b);
    }
}

FacetViewType::~FacetViewType()
{
    delete d;
}

void FacetViewType::doButtonChanged(QAbstractButton* button)
{
    Query::OrTerm orTerm;
    TypeToolButton* b = qobject_cast<TypeToolButton*>(button);
    switch (b->getType()) {
        case TypeToolButton::All:
            // send and invalid term: the type query part is gone
            getFacet()->setTerm(Query::Term());
            break;
        case TypeToolButton::Documents:
            getFacet()->setTerm(Query::ResourceTypeTerm(Types::Class(Nepomuk::Vocabulary::NFO::Document())));
            break;
        case TypeToolButton::Media:
            orTerm.addSubTerm(Query::ResourceTypeTerm(Types::Class(Nepomuk::Vocabulary::NFO::Audio())));
            orTerm.addSubTerm(Query::ResourceTypeTerm(Types::Class(Nepomuk::Vocabulary::NFO::Video())));
            // need to check also the mimetype
            orTerm.addSubTerm(Query::ComparisonTerm(Nepomuk::Vocabulary::NIE::mimeType(), Query::LiteralTerm(QLatin1String("video"))));
            orTerm.addSubTerm(Query::ComparisonTerm(Nepomuk::Vocabulary::NIE::mimeType(), Query::LiteralTerm(QLatin1String("audio"))));
            getFacet()->setTerm(orTerm);
            break;
        case TypeToolButton::Images:
            getFacet()->setTerm(Query::ResourceTypeTerm(Types::Class(Nepomuk::Vocabulary::NFO::Image())));
            break;
        default:
            // not used
            break;
    }
    getFacet()->emitQueryTermChanged(Query::Term());
}

#include "facetviewtype.moc"
